import click
import sys
from urlchecker_bot import create_bot


@click.command(short_help="Runs url checker bot.")
@click.option(
    "--run",
    "-r",
    help="The bot operation mode to run.",
    show_default=True,
    default="status",
    type=click.Choice(["crawl", "status"]),
)
@click.option(
    "--sqlite", "-s", help="The path of the sqlite DB. (default: :memory:)"
)
@click.option("--nameserver", "-n", help="The IP of the DNS server.")
@click.option("--url", "-u", help="The url to check.")
@click.option("--domain", "-d", help="The domain to check.")
@click.option("--timeout", "-t", help="The timeout value.")
@click.option(
    "--configuration", "-f", help="The path of the configuration file."
)
@click.option(
    "--reload/--no-reload",
    default=False,
    help="Reload the configuration file between each crawl.",
    show_default=True,
)
@click.option(
    "--output",
    "-o",
    help="The status output format.",
    type=click.Choice(["plain", "json"]),
    default="plain",
    show_default=True,
)
def runUrlChecker(
    run,
    sqlite,
    nameserver,
    url,
    domain,
    timeout,
    configuration,
    reload,
    output,
):

    # click.echo("Running url checker bot")
    mapping = {}
    if url:
        mapping["URL"] = url
        mapping["DOMAIN"] = ""
    if domain:
        mapping["DOMAIN"] = domain
        if not url:
            mapping["URL"] = ""
    if sqlite:
        mapping["SQLITE"] = sqlite
    if nameserver:
        mapping["NAMESERVER"] = nameserver
    if reload:
        mapping["RELOAD"] = str(reload)
    mapping["FORMAT"] = output
    bot = create_bot(cfgfile=configuration, mapping=mapping)
    return bot.run(run)


if __name__ == "__main__":
    sys.exit(runUrlChecker())
